#!/usr/bin/python

import align_steinar 
import fasta_steinar 
import record_steinar
import extra_steinar
import sable
import os
import pickle
import sys 
import glob

def main(filename, savefile=None): 

	seq_records  = record_steinar.parse_seq_record(filename)
	mega_hash    = align_steinar.vibrio_parser('/home/genome/db/tmp/all/total.fasta')
	count        = 0
 	file_root    = filename.split('.')[0]
	
	for i in seq_records.get_records():
		count += 1
		ss_org = 'vibrio_cholerae'


		""" seperate bac into individual files and run fasta"""
		temp_file_name  = "%s_%s.tmp" % (file_root,count)
		temp_file       = open(temp_file_name, 'w')
		temp_file.write(">temp\n%s" %i.seq)
		temp_file.close()
		i.fasta_result  = fasta_steinar.parse_fasta(temp_file_name, mega_hash)
		
		""" create msf file and run alignment """
		temp_file_name  = "%s_%s.msf" %(file_root, count)
		temp_file       = open(temp_file_name, 'w')
		temp_file.write(i.get_aln())
		temp_file.close()
		temp_out_file   = "%s_%s.aln" %(file_root, count)
		i.align_result = align_steinar.parse_alignment(temp_file_name, temp_out_file)
		

		""" ensure psi and sable are getting the right inputs """
		temp_sequence = i.align_result.get_seqs()[ss_org]
		temp_fasta    = '>%s\n%s\n' %(ss_org, temp_sequence)
		
		""" extra data like location """
		loc    = {} 
		for  org, seq in i.align_result.get_seqs().items(): 
			loc[org] = extra_steinar.pred_loc(seq)
			if org == ss_org:
				temp_file_name = "%s_%s" %(file_root, count)
				i.sstructure   = extra_steinar.psi_pred(temp_file_name, temp_fasta)
		i.location = loc
		
		""" run sable """
		for org, seq in i.align_result.get_seqs().items():
			if org == ss_org: 
				obj      = sable.runSable(temp_fasta)
				i.ss     = obj.getSStructure(org)
				i.sa     = obj.getSAccessibility(org)
				i.ssconf = obj.getSSConf(org)
				i.saconf = obj.getSAConf(org)
			
		""" dump records """	
		temp_file_name = "%s_%s.stn" %(file_root, count)
		temp_file      = open(temp_file_name, 'w')
		temp_file.write(i.get_stn())
		temp_file.close()
		

	if savefile: 

		""" dumps file for future reference """
		
		temp_file = open(savefile, 'w')
		pickle.Pickler(temp_file, protocol=2).dump(seq_records)
		temp_file.close()
		
	return seq_records	


def clean_up(): 
	clean = ['.ss', '.ss2','.tmp', '.dnd', '.msf', '.fasta', '.pyc', '.aln', '.stn~', '.dnd~', '.msf~', '.fasta~', '.py~', '.aln~', '.tmp~']
	for filename in os.listdir('.'): 
		pth, ext = os.path.splitext(filename)
		if ext in clean: os.remove(filename)
		
if __name__ == '__main__': 
	#filelist = glob.glob('*.tab')
	#input = sys.argv[1]
	filelist = ['001_c02.cds.tab', '003_h03.cds.tab']
	for file in filelist: 
		seq_records = main('%s'% file, '%s.pickle' % file)
		clean_up()
