#!/usr/bin/python

import re, os 
from chris_utils import reverse_complement, translate


class bac_seq: 

	def __init__(self, filename): 		self.set_sequence(filename)
		
	def set_sequence(self, filename): 
		header     = re.compile(">(.*?)\s")
		input      = open(filename, 'r')
		self.title = header.match(input.readline()).group(1)
		self.seq   = re.sub('\n|\r', '', input.read())
	
	def get_sequence(self, complement, start, stop): 
		seq = self.seq[int(start)-1:int(stop)]
		if complement: return translate(reverse_complement(seq))
		else         : return translate(seq)

	def get_title(self): return self.title	

class seq_record:

	orgs = ['vibrio_vulnificus_YJ016',
		'vibrio_vulnificus_CMCP6',	
		'vibrio_parahaemolyticus',	
		'vibrio_cholerae',	
		'vibrio_fisheria',
		'photobacterium_profundum']

	def __init__(self): 
		self.seq          = None
		self.fasta_result = None
		self.align_result = None
		self.location     = None
		self.sstruct      = None
		self.ss           = None
		self.ssconf       = None
		self.sa           = None
		self.saconf       = None


	def get_prop(self, prop): 
		if hasattr(self, prop): return getattr(self, prop)
		else                  : return 

	def get_aln(self): 
		result = [">%s\n%s\n" %('vibrio_salmonicidia', self.seq)]
		result.append(self.fasta_result.get_aln())
		return "".join(result)

	def get_stn(self):
		result  = []
		for org in seq_record.orgs: 
			ref = self.fasta_result.get_record(org).ref
			exp = self.fasta_result.get_record(org).exp
			seq = self.align_result.get_record(org).seq
			loc = self.location[org]
			result.append(">%s|%s|%s|%s\n%s\n" %(org, ref, exp, loc, seq))
			if org == 'vibrio_fisheria': 
				org     = 'vibrio_salmonicidia'	
				seq     = self.align_result.get_record(org).seq
				loc     = self.location[org]	
				product = self.get_prop('product')
				go      = self.get_prop('GO_component')
				result.append(">%s|%s|%s|%s\n%s\n" %(org, product, go, loc,  seq))
		seq = self.align_result.get_record('vibrio_cholerae').seq 
		result.append(">Vibrio_cholera secondary structure\n%s\n"              % self.map_stn(seq, self.sstructure))	
		result.append(">Vibrio_cholera secondary sable structure\n%s\n"        % self.map_stn(seq, self.ss))	
		result.append(">Vibrio_cholera secondary sable structure conf \n%s\n"  % self.map_stn(seq, self.ssconf))	
		result.append(">Vibrio_cholera solvent accessibility \n%s\n"           % self.map_stn(seq, self.sa))
		result.append(">Vibrio_cholera solvent accessibility conf \n%s\n"      % self.map_stn(seq, self.saconf))
		return "".join(result)

	def map_stn(self, seq1, seq2):
		temp, count  = list(seq1), 0
		for i in range(len(seq1)): 
			if  not seq1[i] == '-':
				temp[i] =  seq2[count]
				count   += 1
			if count == len(seq2): break		
		return "".join(temp)
		
class seq_result: 

	def __init__(self)           : self.records = []
	def add_record(self, seq_rec): self.records.append(seq_rec)
	def get_records(self)        : return self.records

	
def parse_seq_record(tab_file):

	input          = open(tab_file, 'r')
	bac_file       = re.match('#file=(.*?)#', input.readline()).group(1)
	bac            = bac_seq(bac_file)
	cds            = re.compile("FT\s+CDS\s+(complement)?.*?(\d+)\.\.(\d+)")
	ft             = re.compile("FT\s+\/(.*?)=(.*?)$")
	ext            = re.compile("FT\s+(.*?)$")
	total          = seq_result()
	total.tab_file = bac.get_title()
	
	for line in input.readlines(): 
		result = cds.match(line)
		if result: 
			complement, start, stop = result.groups()
			curr_rec                    = seq_record()
			curr_rec.complement         = complement
			curr_rec.start              = start
			curr_rec.stop               = stop
			curr_rec.seq                = bac.get_sequence(complement, start, stop)
			total.add_record(curr_rec)
			continue
		
		result =ft.match(line)
		if result:
			curr_attr = result.group(1)
			setattr(curr_rec, curr_attr, result.group(2))
			continue
		
		result = ext.match(line)
		if result:
			stub = getattr(curr_rec, curr_attr)
			stub = stub + result.group(1)
			setattr(curr_rec, curr_attr, stub)
			continue
		
	return total 	
		
if __name__ == '__main__': parse_seq_record('C1004.cds.tab')
