#!/usr/bin/python

import os, re 


class fasta_record: 

	def __init__(self): 

		self.id       = None
		self.ref      = None
		self.org      = None
		self.length   = None
		self.opts     = None
		self.bits     = None
		self.exp      = None
		self.seq = None
	
	def __str__(self): 
		return "%s %s %s opts:%s bits:%s exp:%s id:%s \n" %(self.org, self.length, self.ref, self.opts, self.bits,  self.exp, self.id)


class fasta_result: 

	orgs = {  'CMPC6'           : 'vibrio_vulnificus_CMCP6',
		  'yj106'           : 'vibrio_vulnificus_YJ016',
		  'cholera'        : 'vibrio_cholerae', 
		  'parahaemolyticus': 'vibrio_parahaemolyticus', 
		  'fisheria'        : 'vibrio_fisheria',
		  'profundus'       : 'photobacterium_profundum'} 
	
	refs = {  'gi'		    :  re.compile("\>gi\|(.*?)\|"),
		  'sp'              :  re.compile("\>(\w+?) ")}		
		  
	def __init__(self): self.records = {}

	def add_record(self, record): 
		record.org     = self.get_org(record.id)
		record.ref     = self.get_ref(record.id)
		if not self.records.has_key(record.org): self.records[record.org] = [record]
		else                                   : self.records[record.org].append(record)
	
	def get_ref(self, title):
		for key, item in fasta_result.refs.items(): 
			result = item.match(title) 
			if result: return "%s:%s" %(key, result.group(1))
				
	def get_org(self, title):	
		print 'can not identify organism from title %s' % title 
		for key, item in fasta_result.orgs.items(): 
			if  re.search(key, title): return  item
		print title 	
		raise 'organism unknown'	
		
	def get_record(self, org):
			
		try: 
			temp = self.records[org]
			temp.sort(self.sort_by_bits)
			return temp[0]
		except: pass 

	def get_aln(self): 
		result = []
		for org in  fasta_result.orgs.values():	result.append(">%s\n%s\n" %(org, self.get_record(org).seq))
		return "".join(result)	


	def sort_by_bits(self, a, b): return cmp(float(a.exp), float(b.exp))
	

def parse_fasta(filename, mega_hash): 

	""" sets up fasta34_t command line and execute """
	prog   = '/home/genome/fasta/fasta34_t'
	db     = '/home/genome/db/tmp/all/total.fasta'
	libs   = '/home/genome/fasta/fastalibs'
	output = "%s.fasta" % filename
	cmd    = "%s  -l %s -p -H -q -b 200 -w 400 -d 0 %s %s -O %s"  %(prog, libs,  filename, db, output)
	os.system(cmd)

	""" parse output file """
	
	input = open(output, 'r')
	entry = re.compile("(.*?)\s{10,}\((.*?)\)\s+(\d.*?)\s+(\d.*?)\s+(\d.*?)$")
	total = fasta_result()
	for line in input.readlines(): 
		result = entry.match(line) 
		if result:
			record = fasta_record()
			id, length, opts, bits, exp = result.groups()
			record.id       = ">%s" %id[:-1]
			record.length   = length
			record.bits     = bits
			record.exp      = exp
			record.opts     = opts
			record.seq      = mega_hash.get_entry(record.id[0:14])
			total.add_record(record)
	input.close()
	return total
			

if __name__ == '__main__': 
	from align_steinar import vibrio_parser
	mega_hash = vibrio_parser('vibrio_all_aa')
	parse_fasta('1.tmp', mega_hash)	
	
